@@ -42,10 +42,11 @@ directory as the application's script files.
 This module allows applications to specify a search path for resources.
 Relative paths are taken to be relative to the application's ``__main__``
 module. ZIP files can appear on the path; they will be searched inside.  The
-resource module also behaves as expected when applications are bundled using py2exe or py2app.
+resource module also behaves as expected when applications are bundled using
+Freezers such as PyInstaller, py2exe, py2app, etc..
 
-As well as providing file references (with the :py:func:`file` function), the
-resource module also contains convenience functions for loading images,
+In addition to providing file references (with the :py:func:`file` function),
+the resource module also contains convenience functions for loading images,
 textures, fonts, media and documents.
 
 3rd party modules or packages not bound to a specific application should
@@ -61,7 +62,7 @@ is a list of locations to search for resources.  Locations are searched in the
 order given in the path.  If a location is not valid (for example, if the
 directory does not exist), it is skipped.
 
-Locations in the path beginning with an ampersand (''@'' symbol) specify
+Locations in the path beginning with an "at" symbol (''@'') specify
 Python packages.  Other locations specify a ZIP archive or directory on the
 filesystem.  Locations that are not absolute are assumed to be relative to the
 script home.  Some examples::
@@ -74,10 +75,9 @@ script home.  Some examples::
     # by the `res/images` directory.
     path = ['@levels.level1', 'res/images']
 
-Paths are always case-sensitive and forward slashes are always used as path
-separators, even in cases when the filesystem or platform does not do this.
-This avoids a common programmer error when porting applications between
-platforms.
+Paths are always **case-sensitive** and **forward slashes are always used**
+as path separators, even in cases when the filesystem or platform does not do this.
+This avoids a common programmer error when porting applications between platforms.
 
 The default path is ``['.']``.  If you modify the path, you must call
 :py:func:`reindex`.
@@ -322,7 +322,7 @@ class Loader(object):
             path = ['.']
         if isinstance(path, str):
             path = [path]
-        self.path = [os.path.normpath(p) for p in path]
+        self.path = list(path)
         self._script_home = script_home or get_script_home()
         self._index = None
 
@@ -364,6 +364,7 @@ class Loader(object):
                     path = ''  # interactive
             elif not os.path.isabs(path):
                 # Add script base unless absolute
+                assert r'\\' not in path, "Backslashes are not permitted in relative paths"
                 path = os.path.join(self._script_home, path)
 
             if os.path.isdir(path):
@@ -439,9 +440,8 @@ class Loader(object):
                 return None
 
     def _index_file(self, name, location):
-        normed_name = os.path.normpath(name)
-        if normed_name not in self._index:
-            self._index[normed_name] = location
+        if name not in self._index:
+            self._index[name] = location
 
     def file(self, name, mode='rb'):
         """Load a resource.
@@ -455,13 +455,12 @@ class Loader(object):
 
         :rtype: file object
         """
-        normed_name = os.path.normpath(name)
         self._require_index()
         try:
-            location = self._index[normed_name]
-            return location.open(normed_name, mode)
+            location = self._index[name]
+            return location.open(name, mode)
         except KeyError:
-            raise ResourceNotFoundException(normed_name)
+            raise ResourceNotFoundException(name)
 
     def location(self, name):
         """Get the location of a resource.
