@@ -1,6 +1,7 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
+# Copyright (c) 2008-2019 pyglet contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -104,7 +105,6 @@ __version__ = '$Id$'
 
 import math
 import sys
-import warnings
 
 from pyglet.gl import *
 from pyglet import clock
@@ -112,7 +112,7 @@ from pyglet import event
 from pyglet import graphics
 from pyglet import image
 
-_is_pyglet_docgen = hasattr(sys, 'is_pyglet_docgen') and sys.is_pyglet_docgen
+_is_pyglet_doc_run = hasattr(sys, "is_pyglet_doc_run") and sys.is_pyglet_doc_run
 
 
 class SpriteGroup(graphics.Group):
@@ -387,18 +387,18 @@ class Sprite(event.EventDispatcher):
         else:
             vertex_format = 'v2i/%s' % self._usage
         if self._batch is None:
-            self._vertex_list = graphics.vertex_list(4, vertex_format,
-                'c4B', ('t3f', self._texture.tex_coords))
+            self._vertex_list = graphics.vertex_list(
+                4, vertex_format, 'c4B', ('t3f', self._texture.tex_coords))
         else:
-            self._vertex_list = self._batch.add(4, GL_QUADS, self._group,
-                vertex_format, 'c4B', ('t3f', self._texture.tex_coords))
+            self._vertex_list = self._batch.add(
+                4, GL_QUADS, self._group, vertex_format, 'c4B', ('t3f', self._texture.tex_coords))
         self._update_position()
         self._update_color()
 
     def _update_position(self):
         img = self._texture
-        scale_x = self._scale * self.scale_x
-        scale_y = self._scale * self.scale_y
+        scale_x = self._scale * self._scale_x
+        scale_y = self._scale * self._scale_y
         if not self._visible:
             vertices = (0, 0, 0, 0, 0, 0, 0, 0)
         elif self._rotation:
@@ -461,22 +461,6 @@ class Sprite(event.EventDispatcher):
         self._x, self._y = pos
         self._update_position()
 
-    def set_position(self, x, y):
-        """Set the X and Y coordinates of the sprite simultaneously.
-
-        :Parameters:
-            `x` : int
-                X coordinate of the sprite.
-            `y` : int
-                Y coordinate of the sprite.
-
-        :deprecated: Set the X, Y coordinates via sprite.position instead.
-        """
-        self._x = x
-        self._y = y
-        self._update_position()
-        warnings.warn("Use position property instead.", DeprecationWarning)
-
     @property
     def x(self):
         """X coordinate of the sprite.
@@ -692,7 +676,7 @@ class Sprite(event.EventDispatcher):
         self._vertex_list.draw(GL_QUADS)
         self._group.unset_state_recursive()
 
-    if _is_pyglet_docgen:
+    if _is_pyglet_doc_run:
         def on_animation_end(self):
             """The sprite animation reached the final frame.
 
@@ -703,4 +687,5 @@ class Sprite(event.EventDispatcher):
             :event:
             """
 
+
 Sprite.register_event_type('on_animation_end')
